RB = {}
RB.name = "RaidBuffsHealer"
boss1 = false
boss2 = false
boss3 = false 
debug = false

RB.lifeStealIds = {
  [88634] = true,
  [80020] = true
}

RB.magStealIds = {
  [62796] = true,
  [27032] = true
}

RB.offBalanceIds = {
  [63003] = true,
  [62988] = true,
  [63108] = true
}

-- Important Buffs:
-- The Morag Tong:	34384
-- Night Mother's Gaze: 34386
-- Sunderflame:		60416
-- Lifesteal:		88634
-- Magsteal:		62796
-- Minor Vulnerability:	81519
-- Power of the Light:	27587
-- Off-Balance:		62988 63108 63003
-- OB Immunity:		102771
-- Engulfing:		34050

function RB.Init()
  EVENT_MANAGER:RegisterForEvent(RB.name, EVENT_BOSSES_CHANGED, RB.BossUpdate)
  EVENT_MANAGER:RegisterForEvent(RB.name, EVENT_ZONE_CHANGED, RB.BossUpdate)
  EVENT_MANAGER:RegisterForEvent(RB.name, EVENT_ZONE_UPDATE, RB.BossUpdate)
  RB.savedVariables = ZO_SavedVars:New("RBHSavedVariables", 1, nil, {})
  RB.RestorePosition()
  EVENT_MANAGER:RegisterForUpdate('RBHUpdate', 200, RB.buffUpdate)
  RB.BossUpdate()
end

function RB.OnIndicatorMoveStop()
    RB.savedVariables.left = BossFrame:GetLeft()
    RB.savedVariables.top = BossFrame:GetTop()
    RB.RestorePosition()
end

function RB.RestorePosition()
  if RB.savedVariables.left and RB.savedVariables.top then
    local left = RB.savedVariables.left
    local top = RB.savedVariables.top

    BossFrame:ClearAnchors()
    BossFrame:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top)
    BossFrame2:ClearAnchors()
    BossFrame2:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top+75)
    BossFrame3:ClearAnchors()
    BossFrame3:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top+150)
  else
    local left = 100
    local top = 100

    BossFrame:ClearAnchors()
    BossFrame:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top)
    BossFrame2:ClearAnchors()
    BossFrame2:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top+75)
    BossFrame3:ClearAnchors()
    BossFrame3:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top+150)
  end
end

function RB.time(nd)
  local time = math.floor((nd - GetGameTimeMilliseconds()/1000) * 10 + 0.5)/10
  return time
end

function RB.BossUpdate()
  if DoesUnitExist('boss1') == true then
    BossFrameBoss1:SetText(GetUnitName('boss1'))
    BossFrame:SetHidden(false)
    boss1 = true
  else
    BossFrameBoss1:SetText('')
    BossFrame:SetHidden(true)
    boss1 = false
  end

  if DoesUnitExist('boss2') == true then
    BossFrame2Boss2:SetText(GetUnitName('boss2'))
    BossFrame2:SetHidden(false)
    boss2 = true
  else
    BossFrame2Boss2:SetText('')
    BossFrame2:SetHidden(true)
    boss2 = false
  end

  if DoesUnitExist('boss3') == true then
    BossFrame3Boss3:SetText(GetUnitName('boss3'))
    BossFrame3:SetHidden(false)
    boss3 = true
  else
    BossFrame3Boss3:SetText('')
    BossFrame3:SetHidden(true)
    boss3 = false
  end
end

function RB.buffUpdate()
  if boss1 == true then
    local updates = {false, false, false, false, false}
    local b1NumBuffs = GetNumBuffs('boss1')
    for i = 1, b1NumBuffs do
      local _,_,nd,_,_,_,_,_,_,_,ID = GetUnitBuffInfo('boss1',i)
      if RB.magStealIds[ID] then 	-- magsteal
        BossFrameB1MagstealTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[1] = true
      elseif RB.lifeStealIds[ID] then	-- lifesteal
        BossFrameB1LifestealTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[2] = true
      elseif ID == 81519 then 	-- minor vuln
        BossFrameB1MinorVulnTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[3] = true
      elseif RB.offBalanceIds[ID] then	-- off-balance
        BossFrameB1OBTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[4] = true
      elseif ID == 102771 then 	-- off-balance immunity
        BossFrameB1ImmunityTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[5] = true
      end

    end
    if updates[1] == true then	-- magsteal
      BossFrameB1Magsteal:SetColor(0, 255, 0)
    else
      BossFrameB1Magsteal:SetColor(255, 255, 255)
      BossFrameB1MagstealTime:SetText('0.0')
    end
    if updates[2] == true then	-- lifesteal
      BossFrameB1Lifesteal:SetColor(0, 255, 0)
    else
      BossFrameB1Lifesteal:SetColor(255, 255, 255)
      BossFrameB1LifestealTime:SetText('0.0')
    end
    if updates[3] == true then	-- minor vuln
      BossFrameB1MinorVuln:SetColor(0, 255, 0)
    else
      BossFrameB1MinorVuln:SetColor(255, 255, 255)
      BossFrameB1MinorVulnTime:SetText('0.0')
    end
    if updates[4] == true then	-- off-balance
      BossFrameB1OffBalance:SetColor(0, 255, 0)
    else
      BossFrameB1OffBalance:SetColor(255, 255, 255)
      BossFrameB1OBTime:SetText('0.0')
    end
    if updates[5] == true then	-- off-balance immunity
      BossFrameB1Immunity:SetColor(255, 0, 0)
    else
      BossFrameB1Immunity:SetColor(255, 255, 255)
      BossFrameB1ImmunityTime:SetText('0.0')
    end
  end

  if boss2 == true then
    local updates = {false, false, false, false, false}
    local b2NumBuffs = GetNumBuffs('boss2')
    for i = 1, b2NumBuffs do
      local _,_,nd,_,_,_,_,_,_,_,ID = GetUnitBuffInfo('boss2',i)
      if RB.magStealIds[ID] then 	-- magsteal
        BossFrame2B2MagstealTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[1] = true
      elseif RB.lifeStealIds[ID] then	-- lifesteal
        BossFrame2B2LifestealTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[2] = true
      elseif ID == 81519 then 	-- minor vuln
        BossFrame2B2MinorVulnTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[3] = true
      elseif RB.offBalanceIds[ID] then	-- off-balance
        BossFrame2B2OBTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[4] = true
      elseif ID == 102771 then 	-- off-balance immunity
        BossFrame2B2ImmunityTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[5] = true
      end

    end
    if updates[1] == true then	-- magsteal
      BossFrame2B2Magsteal:SetColor(0, 255, 0)
    else
      BossFrame2B2Magsteal:SetColor(255, 255, 255)
      BossFrame2B2MagstealTime:SetText('0.0')
    end
    if updates[2] == true then	-- lifesteal
      BossFrame2B2Lifesteal:SetColor(0, 255, 0)
    else
      BossFrame2B2Lifesteal:SetColor(255, 255, 255)
      BossFrame2B2LifestealTime:SetText('0.0')
    end
    if updates[3] == true then	-- minor vuln
      BossFrame2B2MinorVuln:SetColor(0, 255, 0)
    else
      BossFrame2B2MinorVuln:SetColor(255, 255, 255)
      BossFrame2B2MinorVulnTime:SetText('0.0')
    end
    if updates[4] == true then	-- off-balance
      BossFrame2B2OffBalance:SetColor(0, 255, 0)
    else
      BossFrame2B2OffBalance:SetColor(255, 255, 255)
      BossFrame2B2OBTime:SetText('0.0')
    end
    if updates[5] == true then	-- off-balance immunity
      BossFrame2B2Immunity:SetColor(255, 0, 0)
    else
      BossFrame2B2Immunity:SetColor(255, 255, 255)
      BossFrame2B2ImmunityTime:SetText('0.0')
    end
  end

  if boss3 == true then
    local updates = {false, false, false, false, false}
    local b3NumBuffs = GetNumBuffs('boss3')
    for i = 1, b3NumBuffs do
      local _,_,nd,_,_,_,_,_,_,_,ID = GetUnitBuffInfo('boss3',i)
      if RB.magStealIds[ID] then 	-- magsteal
        BossFrame3B3MagstealTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[1] = true
      elseif RB.lifeStealIds[ID] then	-- lifesteal
        BossFrame3B3LifestealTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[2] = true
      elseif ID == 81519 then 	-- minor vuln
        BossFrame3B3MinorVulnTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[3] = true
      elseif RB.offBalanceIds[ID] then	-- off-balance
        BossFrame3B3OBTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[4] = true
      elseif ID == 102771 then 	-- off-balance immunity
        BossFrame3B3ImmunityTime:SetText(string.format('%.1f',RB.time(nd)))
        updates[5] = true
      end

    end
    if updates[1] == true then	-- magsteal
      BossFrame3B3Magsteal:SetColor(0, 255, 0)
    else
      BossFrame3B3Magsteal:SetColor(255, 255, 255)
      BossFrame3B3MagstealTime:SetText('0.0')
    end
    if updates[2] == true then	-- lifesteal
      BossFrame3B3Lifesteal:SetColor(0, 255, 0)
    else
      BossFrame3B3Lifesteal:SetColor(255, 255, 255)
      BossFrame3B3LifestealTime:SetText('0.0')
    end
    if updates[3] == true then	-- minor vuln
      BossFrame3B3MinorVuln:SetColor(0, 255, 0)
    else
      BossFrame3B3MinorVuln:SetColor(255, 255, 255)
      BossFrame3B3MinorVulnTime:SetText('0.0')
    end
    if updates[4] == true then	-- off-balance
      BossFrame3B3OffBalance:SetColor(0, 255, 0)
    else
      BossFrame3B3OffBalance:SetColor(255, 255, 255)
      BossFrame3B3OBTime:SetText('0.0')
    end
    if updates[5] == true then	-- off-balance immunity
      BossFrame3B3Immunity:SetColor(255, 0, 0)
    else
      BossFrame3B3Immunity:SetColor(255, 255, 255)
      BossFrame3B3ImmunityTime:SetText('0.0')
    end
  end
end

function setup()
  if debug == false then
    BossFrame:SetHidden(false)
    BossFrame2:SetHidden(false)
    BossFrame3:SetHidden(false)
    debug = true
  else
    BossFrame:SetHidden(true)
    BossFrame2:SetHidden(true)
    BossFrame3:SetHidden(true)
    debug = false
  end
end
  
SLASH_COMMANDS["/togglesetup"] = setup


function RB.onAddonLoaded(event, addonName)
  if addonName == RB.name then
    zo_callLater(function()d("|cFF0000WARNING: |rRaidBuffsHealer is no longer being developed, and its features have been added to RaidBuffs. Please download RaidBuffs for coninued support, thank you.")end, 3000)
    RB.Init()
  end
end

EVENT_MANAGER:RegisterForEvent(RB.name, EVENT_ADD_ON_LOADED, RB.onAddonLoaded)
